==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/ModifyVpcTenancyResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyVpcTenancyResponse(returnValue: Option[Boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse = {
    import ModifyVpcTenancyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
      .builder()
      .optionallyWith(returnValue.map(value => value: java.lang.Boolean))(
        _.returnValue
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyVpcTenancyResponse.ReadOnly =
    zio.aws.ec2.model.ModifyVpcTenancyResponse.wrap(buildAwsValue())
}
object ModifyVpcTenancyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyVpcTenancyResponse =
      zio.aws.ec2.model
        .ModifyVpcTenancyResponse(returnValue.map(value => value))
    def returnValue: Option[Boolean]
    def getReturnValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("returnValue", returnValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
  ) extends zio.aws.ec2.model.ModifyVpcTenancyResponse.ReadOnly {
    override val returnValue: Option[Boolean] =
      scala.Option(impl.returnValue()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
  ): zio.aws.ec2.model.ModifyVpcTenancyResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.17.269.1-sources.jar: zio/aws/ec2/model/ModifyVpcTenancyResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyVpcTenancyResponse(
    returnValue: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse = {
    import ModifyVpcTenancyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
      .builder()
      .optionallyWith(returnValue.map(value => value: java.lang.Boolean))(
        _.returnValue
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyVpcTenancyResponse.ReadOnly =
    zio.aws.ec2.model.ModifyVpcTenancyResponse.wrap(buildAwsValue())
}
object ModifyVpcTenancyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyVpcTenancyResponse =
      zio.aws.ec2.model
        .ModifyVpcTenancyResponse(returnValue.map(value => value))
    def returnValue: Optional[Boolean]
    def getReturnValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("returnValue", returnValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
  ) extends zio.aws.ec2.model.ModifyVpcTenancyResponse.ReadOnly {
    override val returnValue: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.returnValue())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcTenancyResponse
  ): zio.aws.ec2.model.ModifyVpcTenancyResponse.ReadOnly = new Wrapper(impl)
}
